summaryrefslogtreecommitdiffstats
path: root/src/datavis3dqml2/declarativebars.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/datavis3dqml2/declarativebars.h')
-rw-r--r--src/datavis3dqml2/declarativebars.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/datavis3dqml2/declarativebars.h b/src/datavis3dqml2/declarativebars.h
index cada9870..a48d953a 100644
--- a/src/datavis3dqml2/declarativebars.h
+++ b/src/datavis3dqml2/declarativebars.h
@@ -160,10 +160,10 @@ public:
Q_INVOKABLE void setBarColor(QColor baseColor, QColor heightColor, QColor depthColor,
bool uniform = true);
// Set tick count and step. Note; tickCount * step should be the maximum possible value of data
// set. Minimum is the absolute minimum possible value a bar can have. This is especially
// important to set if values can be negative.
- Q_INVOKABLE void setTickCount(int tickCount, qreal step, qreal minimum);
+ Q_INVOKABLE void setSegmentCount(int segmentCount, qreal step, qreal minimum);
// TODO: light placement API
@@ -160,10 +160,10 @@ public:
Q_INVOKABLE void setBarColor(QColor baseColor, QColor heightColor, QColor depthColor,
bool uniform = true);
- // Set tick count and step. Note; tickCount * step should be the maximum possible value of data
+ // Set segment count and step. Note; segmentCount * step should be the maximum possible value of data
// set. Minimum is the absolute minimum possible value a bar can have. This is especially
// important to set if values can be negative.